/*******************************************************************************
* Copyright 2009, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

/* This header exports the configuration method(s) defined by this file. */
#include <cyfitter_cfg.h>

/* This header includes all of the necessary type definitions. */
#include <cytypes.h>

/* Standard system includes */
#if !defined(__ARMCC_VERSION)
#include <string.h>
#endif

/* This header contains all of the macros necessary for accessing registers on the device */
#include <cydevice.h>

/* This header contains all of the macros defined based on the users choices in the System DWR as well as instance
   based macros for register access. */
#include <cyfitter.h>

/* This header contains functions needed to enable the digital array */
#include <CyLib.h>

/* The section below contains all of the data used to initialize the device. */
#include <CyDmac.h>

#if defined(__C51__) || defined(__CX51__)
#define CYCODE code
#define CYDATA data
#define CYXDATA xdata
#define CYFAR far
extern void cymemzero(void CYFAR *addr, uint16 size);
extern void cyconfigcpy(uint16 size, const void CYFAR *src, void CYFAR *dest) small;
extern void cyconfigcpycode(uint16 size, const void CYCODE *src, void CYFAR *dest);
#define CYMEMZERO(a,c) cymemzero((a),(c))
#define CYCONFIGCPY(d,s,c) cyconfigcpy((c),(s),(d))
#define CYCONFIGCPYCODE(d,s,c) cyconfigcpycode((c),(s),(d))
#else
#define CYCODE
#define CYDATA
#define CYXDATA
#define CYFAR
#define CYMEMZERO(a,c) cymemset((a),0,(c))
#define CYCONFIGCPY(d,s,c) cymemcpy((d),(s),(c))
#define CYCONFIGCPYCODE(d,s,c) cymemcpy((d),(s),(c))
#endif

/* Disable warnings about pointer truncation and pointer to integer conversion */
#if defined(__ARMCC_VERSION)

#pragma diag_suppress 767,69
#elif defined(__GNUC__)
#pragma GCC diagnostic ignored "-Wpointer-to-int-cast"
#endif

#if defined(__GNUC__) || defined(__ARMCC_VERSION)
#define CYPACKED __attribute__ ((packed))
#define DMAINITSEC __attribute__ ((section (".dma_init")))
#if defined(__ARMCC_VERSION)
#define CY_CFG_MEMORY_BARRIER() __memory_changed()
#else
#define CY_CFG_MEMORY_BARRIER() __sync_synchronize()
#endif
#else
#define CYPACKED
#define DMAINITSEC
#define CY_CFG_MEMORY_BARRIER()
#endif

#define CYDATADECL(name) const uint8 CYCODE name

typedef struct {
	void CYFAR *address;
	uint16 size;
} CYPACKED cfg_memset_t;

typedef struct {
	void CYFAR *dest;
	const void CYCODE *src;
	uint16 size;
} CYPACKED cfg_memcpy_t;

#define CFG_MEMSET_COUNT (sizeof(cfg_memset_list)/sizeof(*cfg_memset_list))
static const cfg_memset_t CYCODE cfg_memset_list [] = {
	/* address, size */
	{(void CYFAR *)(CYDEV_IO_PRT_PRT0_DR), 48},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT4_DR), 48},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT12_DR), 16},
	{(void CYFAR *)(CYDEV_IO_PRT_PRT15_DR), 16},
	{(void CYFAR *)(CYDEV_UCFG_B0_P0_U0_BASE), 4096},
	{(void CYFAR *)(CYDEV_UCFG_B1_P2_U0_BASE), 2048},
	{(void CYFAR *)(CYDEV_UCFG_DSI0_BASE), 2560},
	{(void CYFAR *)(CYDEV_UCFG_DSI12_BASE), 512},
};

CYDATADECL(cfg_byte_table) [] = {
	0x07,
	0x00, 0x64, 0x01, /* Base address 0x006400 */
	/* CYDEV_UWRK_UWRK8_B0_BASE + 0x00000070 */
	0x8C, 0x0D, 
	0x01, 0x03, 0x01, /* Base address 0x010300 */
	/* CYDEV_UCFG_B0_P1_ROUTE_BASE + 0x00000080 */
	0xE2, 0x40, 
	0x01, 0x0C, 0x1A, /* Base address 0x010C00 */
	/* CYDEV_UCFG_B0_P6_U0_BASE */
	0x23, 0x01, 0x2F, 0x01, 0x31, 0x01, 0x3F, 0x01, 0x40, 0x16, 0x45, 0xEC, 0x47, 0x22, 0x48, 0x33, 
	0x49, 0xFF, 0x4A, 0xFF, 0x4B, 0xFF, 0x4F, 0x01, 0x50, 0x18, 0x54, 0x01, 0x59, 0x04, 0x5A, 0x04, 
	0x5B, 0x04, 0x60, 0x40, 0x62, 0x40, 0x64, 0x40, 0x65, 0x40, 0x66, 0x80, 0x68, 0x80, 0x6A, 0x80, 
	0x6C, 0x80, 0x6E, 0x80, 
	0x01, 0x0D, 0x12, /* Base address 0x010D00 */
	/* CYDEV_UCFG_B0_P6_ROUTE_BASE */
	0x27, 0x80, 0x2C, 0x02, 0x2E, 0x02, 0x47, 0x40, 0x4C, 0x08, 0x4D, 0x0A, 0x54, 0x08, 0x56, 0x02, 
	0x5D, 0x4A, 0x5F, 0x80, 0x74, 0x02, 0x77, 0x40, 
	/* CYDEV_UCFG_B0_P6_ROUTE_BASE + 0x00000080 */
	0x8D, 0x40, 0xCA, 0x90, 0xD0, 0x10, 0xD2, 0x20, 0xD6, 0xD0, 0xE2, 0x40, 
	0x01, 0x41, 0x05, /* Base address 0x014100 */
	/* CYDEV_UCFG_DSI1_BASE */
	0x3E, 0x04, 0x6C, 0x01, 0x6E, 0x04, 
	/* CYDEV_UCFG_DSI1_BASE + 0x00000080 */
	0x8C, 0x01, 0xCE, 0x80, 
	0x01, 0x50, 0x02, /* Base address 0x015000 */
	/* CYDEV_UCFG_BCTL0_MDCLK_EN */
	0x00, 0x01, 0x0E, 0x01, 
	0x01, 0x51, 0x01, /* Base address 0x015100 */
	/* CYDEV_IDMUX_DRQ_CTL0 */
	0x11, 0x20, 
};
/* BYTES: 130 */

/* IOPINS0_3 Address: CYDEV_IO_PRT_PRT3_DM0 Size (bytes): 8 */
static CYDATADECL(BS_IOPINS0_3_VAL) [] DMAINITSEC = {
	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00};


#if defined(__C51__) || defined(__CX51__)
extern void cfg_write_bytes_code(void CYCODE *table);
extern void cfg_write_bytes(void CYFAR *table);
#else
/* For 32-bit little-endian architectures */
static void cfg_write_bytes32(void)
{
	unsigned int i, j = 0;
	for (i = 0; i < CY_CFG_BASE_ADDR_COUNT; i++)
	{
		uint32 baseAddr = cy_cfg_addr_table[i];
		uint8 count = baseAddr & 0xFFu;
		baseAddr &= 0xFFFFFF00u;
		while (count--)
		{
			CY_SET_XTND_REG8((void CYFAR *)(baseAddr + cy_cfg_data_table[j].offset), cy_cfg_data_table[j].value);
			j++;
		}
	}
}
#endif

#if defined(__C51__) || defined(__CX51__)
#define CYMEMZERO8(a,c) cymemzero((a),(c))
#define CYCONFIGCPY8(d,s,c) cyconfigcpy((c),(s),(d))
#define CYCONFIGCPYCODE8(d,s,c) cyconfigcpycode((c),(s),(d))
#else
#if defined(__GNUC__) || defined(__ARMCC_VERSION)
__attribute__ ((unused))
#endif
static void cymemzero8(void *addr, unsigned int count)
{
	uint8 *addr8 = (uint8 *)addr;
	while (count--)
	{
		*addr8 = 0;
		addr8++;
	}
}

#if defined(__GNUC__) || defined(__ARMCC_VERSION)
__attribute__ ((unused))
#endif
static void cymemcpy8(void *dest, const void *src, unsigned int count)
{
	uint8 *dest8 = (uint8 *)dest;
	const uint8 *src8 = (const uint8 *)src;

	while (count--)
	{
		*dest8 = *src8;
		dest8++;
		src8++;
	}
}

#define CYMEMZERO8(a,c) cymemzero8((a),(c))
#define CYCONFIGCPY8(d,s,c) cymemcpy8((d),(s),(c))
#define CYCONFIGCPYCODE8(d,s,c) cymemcpy8((d),(s),(c))
#endif

static void ClockSetup(void)
{
	reg32  timeout;
	reg32* timeout_p = &timeout;
	reg8   pllLock;
	CY_SET_XTND_REG24((void CYFAR *)(CYDEV_CLKDIST_DCFG0_CFG0), 0x180018);
	CY_SET_REG8((void CYXDATA *)(CYDEV_SLOWCLK_ILO_CR0), 0x02);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_CR), 0x08);
	CY_SET_REG8((void CYXDATA *)(CYDEV_FASTCLK_IMO_CR), 0x03);
	CY_SET_REG8((void CYXDATA *)(CYDEV_MFGCFG_IMO_TR1), (CY_GET_XTND_REG8(CYDEV_FLSHID_BASE + 0x108)));
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_FASTCLK_PLL_P), 0x0008);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_CR), 0x08);
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_FASTCLK_PLL_CFG0), 0x1051);
	pllLock = 0;
	for (timeout = 14; *timeout_p && (pllLock != 0x03u); timeout--) { pllLock = 0x03u & ((pllLock << 1) | ((CY_GET_REG8(CYDEV_FASTCLK_PLL_SR) & 0x01u) >> 0)); }
	CY_SET_XTND_REG16((void CYFAR *)(CYDEV_CLKDIST_MSTR0), 0x0103);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_MSTR0), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_BCFG0), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_BCFG2), 0x48);
	CY_SET_REG8((void CYXDATA *)(CYDEV_CLKDIST_LD), 0x02);

	CY_SET_REG8((void CYXDATA *)(CYDEV_PM_ACT_CFG2), ((CY_GET_REG8(CYDEV_PM_ACT_CFG2) | 0x01)));
}

/* Analog API Functions */
void AnalogSetDefault(void)
{
	CY_SET_REG8(CYDEV_IO_PRT_PRT3_AMUX, 0x04);
	CY_SET_REG8(CYDEV_IO_PRT_PRT12_AG, 0xAA);
	CY_SET_REG8(CYDEV_ANAIF_RT_DAC1_SW3, 0x01);
	CY_SET_REG8(CYDEV_ANAIF_CFG_PUMP_CR0, 0x44);
}

#define CY_AMUX_UNUSED CYDEV_BOOST_SR

/* Digital routing enable Functions */
static void EnableDigitalRouting() {
	CY_SET_XTND_REG8(CYDEV_UCFG_BCTL0_BANK_CTL, CY_GET_XTND_REG8(CYDEV_UCFG_BCTL0_BANK_CTL) | 0x02);
	CY_SET_XTND_REG8(CYDEV_UCFG_BCTL1_BANK_CTL, CY_GET_XTND_REG8(CYDEV_UCFG_BCTL1_BANK_CTL) | 0x02);
}

/* This function is called by the start-up code for the selected device. */
void cyfitter_cfg(void)
{
	uint8 CYDATA i;

	CY_SET_REG8((void CYXDATA *)(CYDEV_CACHE_CR), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x50 : 0x40));
	CY_SET_REG8((void CYXDATA *)(CYDEV_PHUB_CH0_BASIC_CFG), 0x00);
	CY_SET_REG8((void CYXDATA *)(CYDEV_PHUB_CH1_BASIC_CFG), 0x00);

	CY_SET_XTND_REG8(CYDEV_MFGCFG_MLOGIC_DBG_EN_DBG_EN, (CY_GET_XTND_REG8(CYDEV_MFGCFG_MLOGIC_DBG_EN_DBG_EN) | 0x01));
	for (i = 0; i < CFG_MEMSET_COUNT; i++)
	{
		const cfg_memset_t CYCODE * CYDATA ms = &cfg_memset_list[i];
		CYMEMZERO(ms->address, ms->size);
	}

	cfg_write_bytes_code(cfg_byte_table);

	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT0_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT1_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT2_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT3_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT4_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT5_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT6_BASE), 7);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT12_BASE), 6);
	CYMEMZERO8((void CYFAR *)(CYDEV_PRTDSI_PRT15_BASE), 7);
	CYMEMZERO((void CYFAR *)(CYDEV_PHUB_CFGMEM6_CFG0), 4);
	/* BYTES WRITTEN: 66 */
	EnableDigitalRouting();

	CyEnableDigitalArray();

	CYCONFIGCPYCODE((void CYFAR *)(CYDEV_IO_PRT_PRT3_DM0), (void CYCODE *)(BS_IOPINS0_3_VAL), 8);
	/* BYTES WRITTEN: 8 */

	CY_SET_REG8((void CYXDATA *)(CYDEV_CACHE_CR), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x10 : 0x00));
	ClockSetup();
	CY_SET_REG8((void CYXDATA *)(CYDEV_CACHE_CR), ((CYDEV_INSTRUCT_CACHE_ENABLED) ? 0x50 : 0x40));

	AnalogSetDefault();
}

/* [] END OF FILE */
