/* --------------------------------------------------------------------------
* Copyright 2010, Cypress Semiconductor Corporation.
*
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international
* treaty provisions. Cypress hereby grants to licensee a personal,
* non-exclusive, non-transferable license to copy, use, modify, create
* derivative works of, and compile the Cypress Source Code and derivative
* works for the sole purpose of creating custom software in support of
* licensee product to be used only in conjunction with a Cypress integrated
* circuit as specified in the applicable agreement. Any reproduction,
* modification, translation, compilation, or representation of this
* software except as specified above is prohibited without the express
* written permission of Cypress.
* 
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND,EXPRESS OR IMPLIED,
* WITH REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising
* out of the application or use of any product or circuit described herein.
* Cypress does not authorize its products for use as critical components in
* life-support systems where a malfunction or failure may reasonably be
* expected to result in significant injury to the user. The inclusion of
* Cypress' product in a life-support systems application implies that the
* manufacturer assumes all risk of such use and in doing so indemnifies
* Cypress against all charges.
* 
* Use may be limited by and subject to the applicable Cypress software
* license agreement.
* -----------------------------------------------------------------------------
* Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
*
*****************************************************************************
*  Project Name: DAC_SineWaveGenerator 
*  Device Tested: CY8C3866AXI, CY8C5588AXI
*  Software Version: PSoC Creator Beta 4.1
*  Complier tested: Keil(C51) and GCC
*  Related Hardware: CY8CKIT-001
*****************************************************************************
***************************************************************************** */


/* PROJECT DESCRIPTION 
* A sine LUT is created and the values are updated continuously to a DAC. 
* The update rate and the number of points in the sine look-up table determine the frequency of the output sine wave. 
* The values from the look-up table are updated into the DAC with DMA. 
* The DMA is set to update values on a hardware trigger. 
* The hardware trigger is given with the help of a PWM. 
* The output frequency of the sine wave equals update rate/number of points in the sine look-up table. 
* The example project generates a 10kHz sine wave with 32 points in the sine look-up table and an 
* update rate(PWM frequency) of 320 kHz.
* Oscilloscope is connected to P3[2] to see the DAC output
*/

#include <device.h>
#define TABLE_LENGTH 32
				   
void main()
{
    uint8 sineTable[32] =  {127,152,176,198,217,233,245,252,254,252,245,233,217,198,
                    176,152,127,103,79,57,38,22,10,3,0,3,10,22,38,57,79,103};
    uint8 channel;               
    uint8 td;	
    
    
    /* Start the DAC,PWM and enable the clock */
    
    VDAC8_Start();
    Timer_Start();
    
    #if (defined(__C51__))
    /* Initailize the DMA Channel will Burst count of 1 (to send 1 byte at a time)
    * Request per burst - 1 (every burst needs a new request
    * High byte of source address = 0 (as SRAM is within 16 bit address space)
    * High byte of Destination address = 0 (as it resides within 16 bit address space) */
       
    channel = DMA_DmaInitialize(1, 1, 0, 0);
    
    #else
    
    /* Initailize the DMA Channel will Burst count of 1 (to send 1 byte at a time)
    * Request per burst - 1 (every burst needs a new request
    * High byte of source address = The upper 16 bits of source address is initialized with 
    * only one variable because the base address will be same for all the variables in the 
    * pattern and only the offset changes
    * High byte of destination address = 0 (the UDB control register resides in 16 bit address space */
    
    channel = DMA_DmaInitialize(1, 1, HI16(sineTable), HI16(VDAC8_viDAC8__D) );
    #endif    
    
    /* Allocate the td with the channel that was allocated */
    td = CyDmaTdAllocate();  								 
    
    /* Configure the td to transfer 32 bytes of data with auto increment of source address and no following TD */
    CyDmaTdSetConfiguration(td, TABLE_LENGTH, td, TD_INC_SRC_ADR); 	 
    
    /* Set the lower 16 bits of source address and the destination adddress */
    CyDmaTdSetAddress(td, LO16((uint32)sineTable), LO16((uint32)VDAC8_viDAC8__D) );
    
    
    /* Set tds to be the initial td associated with channel */
    CyDmaChSetInitialTd(channel, td); 					
    
    /* Enable the DMA channel */
    CyDmaChEnable(channel, 1); 							
    
    for(;;)
    {
    
    }
}

/* [] END OF FILE */
